@@ -14,8 +14,8 @@ Usage::
 import sys
 from typing import Any, Dict, List, Type
 
+from boto3.botocore_stubs import ClientError as BotocoreClientError
 from botocore.client import ClientMeta
-from botocore.exceptions import ClientError as Boto3ClientError
 
 from mypy_boto3_codeguru_reviewer.paginator import ListRepositoryAssociationsPaginator
 from mypy_boto3_codeguru_reviewer.type_defs import (
@@ -43,19 +43,19 @@ __all__ = ("CodeGuruReviewerClient",)
 
 
 class Exceptions:
-    AccessDeniedException: Type[Boto3ClientError]
-    ClientError: Type[Boto3ClientError]
-    ConflictException: Type[Boto3ClientError]
-    InternalServerException: Type[Boto3ClientError]
-    NotFoundException: Type[Boto3ClientError]
-    ResourceNotFoundException: Type[Boto3ClientError]
-    ThrottlingException: Type[Boto3ClientError]
-    ValidationException: Type[Boto3ClientError]
+    AccessDeniedException: Type[BotocoreClientError]
+    ClientError: Type[BotocoreClientError]
+    ConflictException: Type[BotocoreClientError]
+    InternalServerException: Type[BotocoreClientError]
+    NotFoundException: Type[BotocoreClientError]
+    ResourceNotFoundException: Type[BotocoreClientError]
+    ThrottlingException: Type[BotocoreClientError]
+    ValidationException: Type[BotocoreClientError]
 
 
 class CodeGuruReviewerClient:
     """
-    [CodeGuruReviewer.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.53/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client)
+    [CodeGuruReviewer.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client)
     """
 
     meta: ClientMeta
@@ -65,12 +65,12 @@ class CodeGuruReviewerClient:
         self, Repository: RepositoryTypeDef, ClientRequestToken: str = None
     ) -> AssociateRepositoryResponseTypeDef:
         """
-        [Client.associate_repository documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.53/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.associate_repository)
+        [Client.associate_repository documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.associate_repository)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.53/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.can_paginate)
         """
 
     def create_code_review(
@@ -81,31 +81,31 @@ class CodeGuruReviewerClient:
         ClientRequestToken: str = None,
     ) -> CreateCodeReviewResponseTypeDef:
         """
-        [Client.create_code_review documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.53/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.create_code_review)
+        [Client.create_code_review documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.create_code_review)
         """
 
     def describe_code_review(self, CodeReviewArn: str) -> DescribeCodeReviewResponseTypeDef:
         """
-        [Client.describe_code_review documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.53/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.describe_code_review)
+        [Client.describe_code_review documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.describe_code_review)
         """
 
     def describe_recommendation_feedback(
         self, CodeReviewArn: str, RecommendationId: str, UserId: str = None
     ) -> DescribeRecommendationFeedbackResponseTypeDef:
         """
-        [Client.describe_recommendation_feedback documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.53/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.describe_recommendation_feedback)
+        [Client.describe_recommendation_feedback documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.describe_recommendation_feedback)
         """
 
     def describe_repository_association(
         self, AssociationArn: str
     ) -> DescribeRepositoryAssociationResponseTypeDef:
         """
-        [Client.describe_repository_association documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.53/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.describe_repository_association)
+        [Client.describe_repository_association documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.describe_repository_association)
         """
 
     def disassociate_repository(self, AssociationArn: str) -> DisassociateRepositoryResponseTypeDef:
         """
-        [Client.disassociate_repository documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.53/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.disassociate_repository)
+        [Client.disassociate_repository documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.disassociate_repository)
         """
 
     def generate_presigned_url(
@@ -116,7 +116,7 @@ class CodeGuruReviewerClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.53/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.generate_presigned_url)
         """
 
     def list_code_reviews(
@@ -131,7 +131,7 @@ class CodeGuruReviewerClient:
         NextToken: str = None,
     ) -> ListCodeReviewsResponseTypeDef:
         """
-        [Client.list_code_reviews documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.53/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.list_code_reviews)
+        [Client.list_code_reviews documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.list_code_reviews)
         """
 
     def list_recommendation_feedback(
@@ -143,14 +143,14 @@ class CodeGuruReviewerClient:
         RecommendationIds: List[str] = None,
     ) -> ListRecommendationFeedbackResponseTypeDef:
         """
-        [Client.list_recommendation_feedback documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.53/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.list_recommendation_feedback)
+        [Client.list_recommendation_feedback documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.list_recommendation_feedback)
         """
 
     def list_recommendations(
         self, CodeReviewArn: str, NextToken: str = None, MaxResults: int = None
     ) -> ListRecommendationsResponseTypeDef:
         """
-        [Client.list_recommendations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.53/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.list_recommendations)
+        [Client.list_recommendations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.list_recommendations)
         """
 
     def list_repository_associations(
@@ -165,7 +165,7 @@ class CodeGuruReviewerClient:
         NextToken: str = None,
     ) -> ListRepositoryAssociationsResponseTypeDef:
         """
-        [Client.list_repository_associations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.53/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.list_repository_associations)
+        [Client.list_repository_associations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.list_repository_associations)
         """
 
     def put_recommendation_feedback(
@@ -175,12 +175,12 @@ class CodeGuruReviewerClient:
         Reactions: List[Literal["ThumbsUp", "ThumbsDown"]],
     ) -> Dict[str, Any]:
         """
-        [Client.put_recommendation_feedback documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.53/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.put_recommendation_feedback)
+        [Client.put_recommendation_feedback documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.put_recommendation_feedback)
         """
 
     def get_paginator(
         self, operation_name: Literal["list_repository_associations"]
     ) -> ListRepositoryAssociationsPaginator:
         """
-        [Paginator.ListRepositoryAssociations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.53/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Paginator.ListRepositoryAssociations)
+        [Paginator.ListRepositoryAssociations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Paginator.ListRepositoryAssociations)
         """
